Source: https://www.cia.gov/library/publications/the-world-factbook/fields/print_2227.html
Afghanistan	0.5 beds/1,000 population (2014)
Albania	2.9 beds/1,000 population (2013)
Algeria	1.9 beds/1,000 population (2015)
Andorra	2.5 beds/1,000 population (2009)
Antigua and Barbuda	3.8 beds/1,000 population (2014)
Argentina	5 beds/1,000 population (2014)
Armenia	4.2 beds/1,000 population (2015)
Australia	3.8 beds/1,000 population (2014)
Austria	7.6 beds/1,000 population (2013)
Azerbaijan	4.7 beds/1,000 population (2013)
Bahamas, The	2.9 beds/1,000 population (2013)
Bahrain	2 beds/1,000 population (2014)
Bangladesh	0.8 beds/1,000 population (2015)
Barbados	5.8 beds/1,000 population (2014)
Belarus	11 beds/1,000 population (2013)
Belgium	6.2 beds/1,000 population (2014)
Belize	1.3 beds/1,000 population (2014)
Benin	0.5 beds/1,000 population (2010)
Bhutan	1.7 beds/1,000 population (2012)
Bolivia	1.1 beds/1,000 population (2014)
Bosnia and Herzegovina	3.5 beds/1,000 population (2013)
Botswana	1.8 beds/1,000 population (2010)
Brazil	2.2 beds/1,000 population (2014)
Brunei	2.7 beds/1,000 population (2015)
Bulgaria	6.8 beds/1,000 population (2013)
Burkina Faso	0.4 beds/1,000 population (2010)
Burma	0.9 beds/1,000 population (2012)
Burundi	0.8 beds/1,000 population (2014)
Cabo Verde	2.1 beds/1,000 population (2010)
Cambodia	0.8 beds/1,000 population (2015)
Cameroon	1.3 beds/1,000 population (2010)
Canada	2.7 beds/1,000 population (2012)
Central African Republic	1 beds/1,000 population (2011)
Chile	2.2 beds/1,000 population (2013)
China	4.2 beds/1,000 population (2012)
Colombia	1.5 beds/1,000 population (2014)
Comoros	2.2 beds/1,000 population (2010)
Costa Rica	1.1 beds/1,000 population (2014)
Croatia	5.6 beds/1,000 population (2015)
Cuba	5.2 beds/1,000 population (2014)
Cyprus	3.4 beds/1,000 population (2013)
Czechia	6.5 beds/1,000 population (2015)
Denmark	2.5 beds/1,000 population (2015)
Djibouti	1.4 beds/1,000 population (2014)
Dominica	3.8 beds/1,000 population (2010)
Dominican Republic	1.6 beds/1,000 population (2014)
Ecuador	1.5 beds/1,000 population (2013)
Egypt	1.6 beds/1,000 population (2014)
El Salvador	1.3 beds/1,000 population (2014)
Equatorial Guinea	2.1 beds/1,000 population (2010)
Eritrea	0.7 beds/1,000 population (2011)
Estonia	5 beds/1,000 population (2015)
Eswatini	2.1 beds/1,000 population (2011)
Ethiopia	0.3 beds/1,000 population (2015)
Faroe Islands	4.1 beds/1,000 population (2015)
Fiji	2.3 beds/1,000 population (2011)
Finland	4.4 beds/1,000 population (2015)
France	6.5 beds/1,000 population (2013)
Gabon	6.3 beds/1,000 population (2010)
Gambia, The	1.1 beds/1,000 population (2011)
Gaza Strip	1.32 beds/1,000 population (2015)
Georgia	2.6 beds/1,000 population (2013)
Germany	8.3 beds/1,000 population (2013)
Ghana	0.9 beds/1,000 population (2011)
Greece	4.3 beds/1,000 population (2015)
Greenland	8.2 beds/1,000 population (2015)
Grenada	3.7 beds/1,000 population (2014)
Guatemala	0.6 beds/1,000 population (2014)
Guinea	0.3 beds/1,000 population (2011)
Guinea-Bissau	1 beds/1,000 population (2009)
Guyana	1.6 beds/1,000 population (2014)
Haiti	0.7 beds/1,000 population (2013)
Honduras	0.7 beds/1,000 population (2014)
Hong Kong	5.33 beds/1,000 population (2016)
Hungary	7 beds/1,000 population (2013)
Iceland	3.4 beds/1,000 population (2015)
India	0.7 beds/1,000 population (2011)
Indonesia	1.2 beds/1,000 population (2015)
Iran	0.2 beds/1,000 population (2014)
Iraq	1.4 beds/1,000 population (2014)
Ireland	2.8 beds/1,000 population (2013)
Israel	3.1 beds/1,000 population (2013)
Italy	3.4 beds/1,000 population (2012)
Jamaica	1.7 beds/1,000 population (2013)
Japan	13.4 beds/1,000 population (2012)
Jordan	1.4 beds/1,000 population (2015)
Kazakhstan	6.7 beds/1,000 population (2013)
Kenya	1.4 beds/1,000 population (2010)
Kiribati	1.9 beds/1,000 population (2015)
Korea, North	13.2 beds/1,000 population (2012)
Korea, South	11.5 beds/1,000 population (2015)
Kuwait	2 beds/1,000 population (2014)
Kyrgyzstan	4.5 beds/1,000 population (2013)
Laos	1.5 beds/1,000 population (2012)
Latvia	5.8 beds/1,000 population (2013)
Lebanon	2.9 beds/1,000 population (2014)
Liberia	0.8 beds/1,000 population (2010)
Libya	3.7 beds/1,000 population (2014)
Lithuania	7.3 beds/1,000 population (2013)
Luxembourg	4.9 beds/1,000 population (2014)
Macedonia	4.4 beds/1,000 population (2013)
Madagascar	0.2 beds/1,000 population (2010)
Malawi	1.3 beds/1,000 population (2011)
Malaysia	1.9 beds/1,000 population (2015)
Maldives	4.3 beds/1,000 population (2009)
Mali	0.1 beds/1,000 population (2010)
Malta	4.7 beds/1,000 population (2014)
Marshall Islands	2.7 beds/1,000 population (2010)
Mauritius	3.59 beds/1,000 population (2016)
Mexico	1.5 beds/1,000 population (2015)
Micronesia, Federated States of	3.2 beds/1,000 population (2009)
Moldova	5.8 beds/1,000 population (2013)
Monaco	13.8 beds/1,000 population (2012)
Mongolia	7 beds/1,000 population (2012)
Montenegro	4 beds/1,000 population (2012)
Morocco	1.1 beds/1,000 population (2014)
Mozambique	0.7 beds/1,000 population (2011)
Namibia	2.7 beds/1,000 population (2009)
Nauru	5 beds/1,000 population (2010)
Nepal	3 beds/1,000 population (2012)
Netherlands	4.7 beds/1,000 population (2009)
New Zealand	2.8 beds/1,000 population (2013)
Nicaragua	0.9 beds/1,000 population (2014)
Norway	3.8 beds/1,000 population (2015)
Oman	1.6 beds/1,000 population (2014)
Pakistan	0.6 beds/1,000 population (2014)
Palau	4.8 beds/1,000 population (2010)
Panama	2.3 beds/1,000 population (2013)
Paraguay	1.3 beds/1,000 population (2011)
Peru	1.6 beds/1,000 population (2014)
Philippines	1 beds/1,000 population (2011)
Poland	6.5 beds/1,000 population (2013)
Portugal	3.4 beds/1,000 population (2013)
Qatar	1.2 beds/1,000 population (2014)
Romania	6.3 beds/1,000 population (2013)
Russia	8.2 beds/1,000 population (2013)
Saint Kitts and Nevis	4.8 beds/1,000 population (2012)
Saint Lucia	1.3 beds/1,000 population (2013)
Saint Vincent and the Grenadines	2.6 beds/1,000 population (2014)
San Marino	3.8 beds/1,000 population (2012)
Sao Tome and Principe	2.9 beds/1,000 population (2011)
Saudi Arabia	2.7 beds/1,000 population (2014)
Senegal	0.3 beds/1,000 population (2008)
Serbia	5.7 beds/1,000 population (2012)
Seychelles	3.6 beds/1,000 population (2011)
Singapore	2.4 beds/1,000 population (2015)
Slovakia	5.8 beds/1,000 population (2015)
Slovenia	4.6 beds/1,000 population (2013)
Solomon Islands	1.4 beds/1,000 population (2012)
Somalia	8.7 beds/1,000 population (2014)
Spain	3 beds/1,000 population (2013)
Sri Lanka	3.6 beds/1,000 population (2012)
Sudan	0.8 beds/1,000 population (2013)
Suriname	3.1 beds/1,000 population (2010)
Sweden	2.4 beds/1,000 population (2015)
Switzerland	4.7 beds/1,000 population (2013)
Syria	1.5 beds/1,000 population (2014)
Tajikistan	4.8 beds/1,000 population (2013)
Tanzania	0.7 beds/1,000 population (2010)
Thailand	2.1 beds/1,000 population (2010)
Timor-Leste	5.9 beds/1,000 population (2010)
Togo	0.7 beds/1,000 population (2011)
Tonga	2.6 beds/1,000 population (2010)
Trinidad and Tobago	3 beds/1,000 population (2014)
Tunisia	2.2 beds/1,000 population (2014)
Turkey	2.7 beds/1,000 population (2013)
Turkmenistan	7.4 beds/1,000 population (2013)
Uganda	0.5 beds/1,000 population (2010)
Ukraine	8.8 beds/1,000 population (2013)
United Arab Emirates	1.2 beds/1,000 population (2013)
United Kingdom	2.8 beds/1,000 population (2013)
United States	2.9 beds/1,000 population (2013)
Uruguay	2.8 beds/1,000 population (2014)
Uzbekistan	4 beds/1,000 population (2013)
Vanuatu	1.7 beds/1,000 population (2008)
Venezuela	0.8 beds/1,000 population (2014)
Vietnam	2.6 beds/1,000 population (2014)
West Bank	1.26 beds/1,000 population (2015)
Yemen	0.7 beds/1,000 population (2014)
Zambia	2 beds/1,000 population (2010)
Zimbabwe	1.7 beds/1,000 population (2011)